@@ -1,16 +1,10 @@
 """ConstructionSet Schema"""
 from pydantic import Field, constr
-from typing import List, Union
 
 from .._base import NoExtraBaseModel
 from ._base import IDdEnergyBaseModel
-from .construction import OpaqueConstructionAbridged, WindowConstructionAbridged, \
-    ShadeConstruction, AirBoundaryConstructionAbridged, OpaqueConstruction, \
-    WindowConstruction, AirBoundaryConstruction
-from .material import EnergyMaterial, EnergyMaterialNoMass, \
-    EnergyWindowMaterialGas, EnergyWindowMaterialGasCustom, \
-    EnergyWindowMaterialGasMixture, EnergyWindowMaterialSimpleGlazSys, \
-    EnergyWindowMaterialBlind, EnergyWindowMaterialGlazing, EnergyWindowMaterialShade
+from .construction import OpaqueConstruction, WindowConstruction, ShadeConstruction, \
+    AirBoundaryConstruction
 
 
 class _FaceSubSetAbridged(NoExtraBaseModel):
@@ -21,7 +15,7 @@ class _FaceSubSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for an OpaqueConstruction for faces with a Surface or '
-            'Adiabatic boundary condition.'
+        'Adiabatic boundary condition.'
     )
 
     exterior_construction: str = Field(
@@ -29,7 +23,7 @@ class _FaceSubSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for an OpaqueConstruction for faces with an Outdoors '
-            'boundary condition.'
+        'boundary condition.'
     )
 
     ground_construction: str = Field(
@@ -37,7 +31,7 @@ class _FaceSubSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for an OpaqueConstruction for faces with a Ground '
-            'boundary condition.'
+        'boundary condition.'
     )
 
 
@@ -68,19 +62,19 @@ class _FaceSubSet(NoExtraBaseModel):
     interior_construction: OpaqueConstruction = Field(
         default=None,
         description='An OpaqueConstruction for walls with a Surface or '
-            'Adiabatic boundary condition.'
+        'Adiabatic boundary condition.'
     )
 
     exterior_construction: OpaqueConstruction = Field(
         default=None,
         description='An OpaqueConstruction for walls with an Outdoors '
-            'boundary condition.'
+        'boundary condition.'
     )
 
     ground_construction: OpaqueConstruction = Field(
         default=None,
         description='An OpaqueConstruction for walls with a Ground '
-            'boundary condition.'
+        'boundary condition.'
     )
 
 
@@ -113,8 +107,8 @@ class ApertureConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for a WindowConstruction for apertures with an '
-            'Outdoors boundary condition, False is_operable property, and a Wall '
-            'face type for their parent face.'
+        'Outdoors boundary condition, False is_operable property, and a Wall '
+        'face type for their parent face.'
     )
 
     window_construction: str = Field(
@@ -122,7 +116,7 @@ class ApertureConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for a WindowConstruction for all apertures with a '
-            'Surface boundary condition.'
+        'Surface boundary condition.'
     )
 
     skylight_construction: str = Field(
@@ -130,8 +124,8 @@ class ApertureConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for a WindowConstruction for apertures with a Outdoors '
-            'boundary condition, False is_operable property, and a RoofCeiling or '
-            'Floor face type for their parent face.'
+        'boundary condition, False is_operable property, and a RoofCeiling or '
+        'Floor face type for their parent face.'
     )
 
     operable_construction: str = Field(
@@ -139,7 +133,7 @@ class ApertureConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for a WindowConstruction for all apertures with an '
-            'Outdoors boundary condition and True is_operable property..'
+        'Outdoors boundary condition and True is_operable property.'
     )
 
 
@@ -151,27 +145,27 @@ class ApertureConstructionSet(NoExtraBaseModel):
     interior_construction: WindowConstruction = Field(
         default=None,
         description='A WindowConstruction for apertures with an '
-            'Outdoors boundary condition, False is_operable property, and a Wall '
-            'face type for their parent face.'
+        'Outdoors boundary condition, False is_operable property, and a Wall '
+        'face type for their parent face.'
     )
 
     window_construction: WindowConstruction = Field(
         default=None,
         description='A WindowConstruction for all apertures with a '
-            'Surface boundary condition.'
+        'Surface boundary condition.'
     )
 
     skylight_construction: WindowConstruction = Field(
         default=None,
         description='A WindowConstruction for apertures with a Outdoors boundary '
-            'condition, False is_operable property, and a RoofCeiling or '
-            'Floor face type for their parent face.'
+        'condition, False is_operable property, and a RoofCeiling or '
+        'Floor face type for their parent face.'
     )
 
     operable_construction: WindowConstruction = Field(
         default=None,
         description='A WindowConstruction for all apertures with an '
-            'Outdoors boundary condition and True is_operable property..'
+        'Outdoors boundary condition and True is_operable property.'
     )
 
 
@@ -185,7 +179,7 @@ class DoorConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for an OpaqueConstruction for all opaque doors with a '
-            'Surface boundary condition.'
+        'Surface boundary condition.'
     )
 
     exterior_construction: str = Field(
@@ -193,7 +187,7 @@ class DoorConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for an OpaqueConstruction for opaque doors with an '
-            'Outdoors boundary condition and a Wall face type for their parent face.'
+        'Outdoors boundary condition and a Wall face type for their parent face.'
     )
 
     overhead_construction: str = Field(
@@ -201,8 +195,8 @@ class DoorConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for an OpaqueConstruction for opaque doors with an '
-            'Outdoors boundary condition and a RoofCeiling or Floor type for '
-            'their parent face.'
+        'Outdoors boundary condition and a RoofCeiling or Floor type for '
+        'their parent face.'
     )
 
     exterior_glass_construction: str = Field(
@@ -210,7 +204,7 @@ class DoorConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for a WindowConstruction for all glass doors with an '
-            'Outdoors boundary condition.'
+        'Outdoors boundary condition.'
     )
 
     interior_glass_construction: str = Field(
@@ -218,7 +212,7 @@ class DoorConstructionSetAbridged(NoExtraBaseModel):
         min_length=1,
         max_length=100,
         description='Identifier for a WindowConstruction for all glass doors with a '
-            'Surface boundary condition.'
+        'Surface boundary condition.'
     )
 
 
@@ -230,32 +224,32 @@ class DoorConstructionSet(NoExtraBaseModel):
     interior_construction: OpaqueConstruction = Field(
         default=None,
         description='An OpaqueConstruction for all opaque doors with a '
-            'Surface boundary condition.'
+        'Surface boundary condition.'
     )
 
     exterior_construction: OpaqueConstruction = Field(
         default=None,
         description='An OpaqueConstruction for opaque doors with an '
-            'Outdoors boundary condition and a Wall face type for their parent face.'
+        'Outdoors boundary condition and a Wall face type for their parent face.'
     )
 
     overhead_construction: OpaqueConstruction = Field(
         default=None,
         description='An OpaqueConstruction for opaque doors with an '
-            'Outdoors boundary condition and a RoofCeiling or Floor type for '
-            'their parent face.'
+        'Outdoors boundary condition and a RoofCeiling or Floor type for '
+        'their parent face.'
     )
 
     exterior_glass_construction: WindowConstruction = Field(
         default=None,
         description='A WindowConstruction for all glass doors with an '
-            'Outdoors boundary condition.'
+        'Outdoors boundary condition.'
     )
 
     interior_glass_construction: WindowConstruction = Field(
         default=None,
         description='A WindowConstruction for all glass doors with a '
-            'Surface boundary condition.'
+        'Surface boundary condition.'
     )
 
 
@@ -294,8 +288,8 @@ class ConstructionSetAbridged(IDdEnergyBaseModel):
         min_length=1,
         max_length=100,
         description='The identifier of a ShadeConstruction to set the reflectance '
-            'properties of all outdoor shades of all objects to which this '
-            'ConstructionSet is assigned.'
+        'properties of all outdoor shades of all objects to which this '
+        'ConstructionSet is assigned.'
     )
 
     air_boundary_construction: str = Field(
@@ -303,7 +297,7 @@ class ConstructionSetAbridged(IDdEnergyBaseModel):
         min_length=1,
         max_length=100,
         description='The identifier of an AirBoundaryConstruction to set the properties '
-            'of Faces with an AirBoundary type.'
+        'of Faces with an AirBoundary type.'
     )
 
 
@@ -340,17 +334,12 @@ class ConstructionSet(ConstructionSetAbridged):
     shade_construction: ShadeConstruction = Field(
         default=None,
         description='A ShadeConstruction to set the reflectance '
-            'properties of all outdoor shades of all objects to which this '
-            'ConstructionSet is assigned.'
+        'properties of all outdoor shades of all objects to which this '
+        'ConstructionSet is assigned.'
     )
 
     air_boundary_construction: AirBoundaryConstruction = Field(
         default=None,
         description='An AirBoundaryConstruction to set the properties '
-            'of Faces with an AirBoundary type.'
+        'of Faces with an AirBoundary type.'
     )
-
-
-if __name__ == '__main__':
-    print(ConstructionSetAbridged.schema_json(indent=2))
-    print(ConstructionSet.schema_json(indent=2))
